==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/jms/src/javax/jms/JMSException.java <==
/*
 * Copyright (c) 1998-2003 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package javax.jms;

/**
 * The main message.
 */
public class JMSException extends Exception {
  private String _errorCode;
  private Exception _cause;
  
  public JMSException(String reason)
  {
    super(reason);
  }
  
  public JMSException(String reason, String errorCode)
  {
    super(reason);

    _errorCode = errorCode;
  }

  public String getErrorCode()
  {
    return _errorCode;
  }

  public Exception getLinkedException()
  {
    return _cause;
  }

  public void setLinkedException(Exception cause)
  {
    _cause = cause;
  }

  public Throwable getCause()
  {
    return _cause;
  }
}

==> resin-4.0.65-src.tar.gz: resin-4.0.65/modules/jms/src/javax/jms/JMSException.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package javax.jms;

/**
 * The main message.
 */
public class JMSException extends Exception {
  private String _errorCode;
  private Exception _cause;
  
  public JMSException(String reason)
  {
    super(reason);
  }
  
  public JMSException(String reason, String errorCode)
  {
    super(reason);

    _errorCode = errorCode;
  }

  public String getErrorCode()
  {
    return _errorCode;
  }

  public Exception getLinkedException()
  {
    return _cause;
  }

  public synchronized void setLinkedException(Exception cause)
  {
    _cause = cause;
  }

}
